@@ -59,5 +59,3 @@ impl_into_arguments_for_arguments!(MySqlArguments);
 impl_column_index_for_row!(MySqlRow);
 impl_column_index_for_statement!(MySqlStatement);
 impl_into_maybe_pool!(MySql, MySqlConnection);
-// required because some databases have a different handling of NULL
-impl_encode_for_option!(MySql);
